==> jc-1.4.0.tar.gz: javax/naming/event/NamingExceptionEvent.h <==
// public class javax.naming.event.NamingExceptionEvent

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 2a0a0ab7bac1fd7f javax_naming_event_NamingExceptionEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_naming_event_NamingExceptionEvent_H_
#define _JC_javax_naming_event_NamingExceptionEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_naming_NamingException$object;
struct _jc_javax_naming_event_EventContext$object;
struct _jc_javax_naming_event_NamingListener$object;

// Typedefs
typedef struct _jc_javax_naming_event_NamingExceptionEvent$sub_refs	_jc_javax_naming_event_NamingExceptionEvent$sub_refs;
typedef struct _jc_javax_naming_event_NamingExceptionEvent$sub_nonrefs	_jc_javax_naming_event_NamingExceptionEvent$sub_nonrefs;
typedef struct _jc_javax_naming_event_NamingExceptionEvent$refs	_jc_javax_naming_event_NamingExceptionEvent$refs;
typedef struct _jc_javax_naming_event_NamingExceptionEvent$nonrefs	_jc_javax_naming_event_NamingExceptionEvent$nonrefs;
typedef struct _jc_javax_naming_event_NamingExceptionEvent$object	_jc_javax_naming_event_NamingExceptionEvent$object;

typedef const struct _jc_javax_naming_event_NamingExceptionEvent$vmethods	_jc_javax_naming_event_NamingExceptionEvent$vmethods;
typedef const struct _jc_javax_naming_event_NamingExceptionEvent$vtable	_jc_javax_naming_event_NamingExceptionEvent$vtable;
typedef const struct _jc_javax_naming_event_NamingExceptionEvent$vtype	_jc_javax_naming_event_NamingExceptionEvent$vtype;

// Constructors
extern void _jc_javax_naming_event_NamingExceptionEvent$method$_init$be64ab4c325d7f3e(_jc_env *, struct _jc_javax_naming_event_NamingExceptionEvent$object *, struct _jc_object *, struct _jc_javax_naming_NamingException$object *);

// Virtual methods
extern void _jc_javax_naming_event_NamingExceptionEvent$method$dispatch$3a7ef28658c9ea97(_jc_env *, struct _jc_javax_naming_event_NamingExceptionEvent$object *, struct _jc_object *);
extern struct _jc_object *_jc_javax_naming_event_NamingExceptionEvent$method$getEventContext$4d00ee253e16f306(_jc_env *, struct _jc_javax_naming_event_NamingExceptionEvent$object *);
extern struct _jc_javax_naming_NamingException$object *_jc_javax_naming_event_NamingExceptionEvent$method$getException$b684b3e119c13e26(_jc_env *, struct _jc_javax_naming_event_NamingExceptionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_naming_event_NamingExceptionEvent$method_info$dispatch$3a7ef28658c9ea97;
extern _jc_method _jc_javax_naming_event_NamingExceptionEvent$method_info$getEventContext$4d00ee253e16f306;
extern _jc_method _jc_javax_naming_event_NamingExceptionEvent$method_info$getException$b684b3e119c13e26;

// Virtual methods structure
struct _jc_javax_naming_event_NamingExceptionEvent$vmethods {
	void	(*dispatch$3a7ef28658c9ea97)(_jc_env *, struct _jc_javax_naming_event_NamingExceptionEvent$object *, struct _jc_object *);
	struct _jc_object	*(*getEventContext$4d00ee253e16f306)(_jc_env *, struct _jc_javax_naming_event_NamingExceptionEvent$object *);
	struct _jc_javax_naming_NamingException$object	*(*getException$b684b3e119c13e26)(_jc_env *, struct _jc_javax_naming_event_NamingExceptionEvent$object *);
};

// Vtable
struct _jc_javax_naming_event_NamingExceptionEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_naming_event_NamingExceptionEvent$vmethods	javax_naming_event_NamingExceptionEvent;
};

// Vtype
struct _jc_javax_naming_event_NamingExceptionEvent$vtype {
	_jc_type			type;
	_jc_javax_naming_event_NamingExceptionEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_event_NamingExceptionEvent$sub_refs {
	struct _jc_javax_naming_NamingException$object	*exception;
};

// Reference instance fields (object)
struct _jc_javax_naming_event_NamingExceptionEvent$refs {
    _jc_javax_naming_event_NamingExceptionEvent$sub_refs	javax_naming_event_NamingExceptionEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_event_NamingExceptionEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_event_NamingExceptionEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_naming_event_NamingExceptionEvent$sub_nonrefs	javax_naming_event_NamingExceptionEvent;
};

// Object instance structure
struct _jc_javax_naming_event_NamingExceptionEvent$object {
	_jc_javax_naming_event_NamingExceptionEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_event_NamingExceptionEvent$vtype	*vtype;
	_jc_javax_naming_event_NamingExceptionEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_event_NamingExceptionEvent$vtype _jc_javax_naming_event_NamingExceptionEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_event_NamingExceptionEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_event_NamingExceptionEvent$class_object;

#endif	/* _JC_javax_naming_event_NamingExceptionEvent_H_ */

==> jc-1.4.6.tar.gz: javax/naming/event/NamingExceptionEvent.h <==
// public class javax.naming.event.NamingExceptionEvent

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 2a0a0ab7bac1fd7f javax_naming_event_NamingExceptionEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_naming_event_NamingExceptionEvent_H_
#define _JC_javax_naming_event_NamingExceptionEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_naming_NamingException$object;
struct _jc_javax_naming_event_EventContext$object;
struct _jc_javax_naming_event_NamingListener$object;

// Typedefs
typedef struct _jc_javax_naming_event_NamingExceptionEvent$sub_refs	_jc_javax_naming_event_NamingExceptionEvent$sub_refs;
typedef struct _jc_javax_naming_event_NamingExceptionEvent$sub_nonrefs	_jc_javax_naming_event_NamingExceptionEvent$sub_nonrefs;
typedef struct _jc_javax_naming_event_NamingExceptionEvent$refs	_jc_javax_naming_event_NamingExceptionEvent$refs;
typedef struct _jc_javax_naming_event_NamingExceptionEvent$nonrefs	_jc_javax_naming_event_NamingExceptionEvent$nonrefs;
typedef struct _jc_javax_naming_event_NamingExceptionEvent$object	_jc_javax_naming_event_NamingExceptionEvent$object;

typedef const struct _jc_javax_naming_event_NamingExceptionEvent$vmethods	_jc_javax_naming_event_NamingExceptionEvent$vmethods;
typedef const struct _jc_javax_naming_event_NamingExceptionEvent$vtable	_jc_javax_naming_event_NamingExceptionEvent$vtable;
typedef const struct _jc_javax_naming_event_NamingExceptionEvent$vtype	_jc_javax_naming_event_NamingExceptionEvent$vtype;

// Constructors
extern void _jc_javax_naming_event_NamingExceptionEvent$method$_init$be64ab4c325d7f3e(_jc_env *, struct _jc_javax_naming_event_NamingExceptionEvent$object *, struct _jc_object *, struct _jc_javax_naming_NamingException$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_naming_event_NamingExceptionEvent$method$dispatch$3a7ef28658c9ea97(_jc_env *, struct _jc_javax_naming_event_NamingExceptionEvent$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_naming_event_NamingExceptionEvent$method$getEventContext$4d00ee253e16f306(_jc_env *, struct _jc_javax_naming_event_NamingExceptionEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_naming_NamingException$object *_jc_javax_naming_event_NamingExceptionEvent$method$getException$b684b3e119c13e26(_jc_env *, struct _jc_javax_naming_event_NamingExceptionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_naming_event_NamingExceptionEvent$method_info$dispatch$3a7ef28658c9ea97;
extern _jc_method _jc_javax_naming_event_NamingExceptionEvent$method_info$getEventContext$4d00ee253e16f306;
extern _jc_method _jc_javax_naming_event_NamingExceptionEvent$method_info$getException$b684b3e119c13e26;

// Virtual methods structure
struct _jc_javax_naming_event_NamingExceptionEvent$vmethods {
	void	(*dispatch$3a7ef28658c9ea97)(_jc_env *, struct _jc_javax_naming_event_NamingExceptionEvent$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getEventContext$4d00ee253e16f306)(_jc_env *, struct _jc_javax_naming_event_NamingExceptionEvent$object *) _JC_JCNI_ATTR;
	struct _jc_javax_naming_NamingException$object	*(*getException$b684b3e119c13e26)(_jc_env *, struct _jc_javax_naming_event_NamingExceptionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_naming_event_NamingExceptionEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_naming_event_NamingExceptionEvent$vmethods	javax_naming_event_NamingExceptionEvent;
};

// Vtype
struct _jc_javax_naming_event_NamingExceptionEvent$vtype {
	_jc_type			type;
	_jc_javax_naming_event_NamingExceptionEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_event_NamingExceptionEvent$sub_refs {
	struct _jc_javax_naming_NamingException$object	*exception;
};

// Reference instance fields (object)
struct _jc_javax_naming_event_NamingExceptionEvent$refs {
    _jc_javax_naming_event_NamingExceptionEvent$sub_refs	javax_naming_event_NamingExceptionEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_event_NamingExceptionEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_event_NamingExceptionEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_naming_event_NamingExceptionEvent$sub_nonrefs	javax_naming_event_NamingExceptionEvent;
};

// Object instance structure
struct _jc_javax_naming_event_NamingExceptionEvent$object {
	_jc_javax_naming_event_NamingExceptionEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_event_NamingExceptionEvent$vtype	*vtype;
	_jc_javax_naming_event_NamingExceptionEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_event_NamingExceptionEvent$vtype _jc_javax_naming_event_NamingExceptionEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_event_NamingExceptionEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_event_NamingExceptionEvent$class_object;

#endif	/* _JC_javax_naming_event_NamingExceptionEvent_H_ */
